"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var chalk_1 = __importDefault(require("chalk"));
var jsonUtils_1 = require("./jsonUtils");
var cbor_1 = __importDefault(require("cbor"));
var msgpackr_1 = require("msgpackr");
var logWrapper_1 = require("./logWrapper");
var handleError = function (err, value, action) {
    logWrapper_1.basicLog.error(err);
    return action === 'decode' ? chalk_1.default.red(value.toString()) : process.exit(1);
};
/**
 * Converts a JSON payload to a Buffer or string based on the specified action.
 * @param value - The JSON payload to convert.
 * @param action - The action to perform on the payload ('decode' or 'encode').
 * @returns The converted payload.
 */
var convertJSON = function (value, action) {
    try {
        return action === 'decode'
            ? (0, jsonUtils_1.jsonStringify)((0, jsonUtils_1.jsonParse)(value.toString()), null, 2)
            : Buffer.from((0, jsonUtils_1.jsonStringify)((0, jsonUtils_1.jsonParse)(value.toString())));
    }
    catch (err) {
        return handleError(err, value, action);
    }
};
/**
 * Converts a CBOR payload to JSON or vice versa.
 * @param value - The CBOR payload to convert.
 * @param action - The action to perform: 'decode' to convert CBOR to JSON, 'encode' to convert JSON to CBOR.
 * @returns The converted payload.
 */
var convertCBOR = function (value, action) {
    try {
        return action === 'decode'
            ? (0, jsonUtils_1.jsonStringify)(cbor_1.default.decodeFirstSync(value), null, 2)
            : cbor_1.default.encodeOne(JSON.parse(value.toString()));
    }
    catch (err) {
        return handleError(err, value, action);
    }
};
/**
 * Converts a MsgPack payload to JSON or vice versa.
 * @param value - The MsgPack payload to convert.
 * @param action - The action to perform: 'decode' to convert MsgPack to JSON, 'encode' to convert JSON to MsgPack.
 * @returns The converted payload.
 */
var convertMsgPack = function (value, action) {
    try {
        return action === 'decode' ? (0, jsonUtils_1.jsonStringify)((0, msgpackr_1.unpack)(value), null, 2) : (0, msgpackr_1.pack)(JSON.parse(value.toString()));
    }
    catch (err) {
        return handleError(err, value, action);
    }
};
/**
 * Converts the payload based on the specified format and action.
 * @param payload - The payload to be converted.
 * @param format - The format in which the payload should be converted. (Optional)
 * @param action - The action to be performed on the payload. (Default: 'decode')
 * @returns The converted payload.
 */
var convertPayload = function (payload, format, action) {
    if (action === void 0) { action = 'decode'; }
    var actions = {
        encode: {
            base64: function () { return Buffer.from(payload.toString(), 'base64'); },
            json: function () { return convertJSON(payload, 'encode'); },
            hex: function () { return Buffer.from(payload.toString().replace(/\s+/g, ''), 'hex'); },
            cbor: function () { return convertCBOR(payload, 'encode'); },
            msgpack: function () { return convertMsgPack(payload, 'encode'); },
            binary: function () { return payload; },
            default: function () { return Buffer.from(payload.toString(), 'utf-8'); },
        },
        decode: {
            base64: function () { return payload.toString('base64'); },
            json: function () { return convertJSON(payload, 'decode'); },
            hex: function () { return payload.toString('hex').replace(/(.{4})/g, '$1 '); },
            cbor: function () { return convertCBOR(payload, 'decode'); },
            msgpack: function () { return convertMsgPack(payload, 'decode'); },
            binary: function () { return payload; },
            default: function () { return payload.toString('utf-8'); },
        },
    };
    var actionSet = actions[action];
    var runAction = actionSet[format || 'default'];
    return runAction ? runAction() : payload;
};
exports.default = convertPayload;
