"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fileDataSplitter = exports.createNextNumberedFileName = exports.appendFile = exports.writeFile = exports.readFile = exports.stringifyToYamlOrJson = exports.parseYamlOrJson = exports.isYaml = exports.fileExists = exports.getPathExtname = exports.processPath = void 0;
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var js_yaml_1 = __importDefault(require("js-yaml"));
var logWrapper_1 = __importDefault(require("./logWrapper"));
var processPath = function (savePath, defaultPath) {
    var filePath = '';
    if (savePath === true && defaultPath) {
        filePath = defaultPath;
    }
    else if (typeof savePath === 'string') {
        filePath = path_1.default.normalize(savePath);
        if (!path_1.default.isAbsolute(filePath)) {
            filePath = path_1.default.resolve(filePath);
        }
    }
    return filePath;
};
exports.processPath = processPath;
var getPathExtname = function (filePath) { return path_1.default.extname(filePath); };
exports.getPathExtname = getPathExtname;
var fileExists = function (filePath) { return fs_1.default.existsSync(filePath); };
exports.fileExists = fileExists;
var isYaml = function (filePath) {
    var fileExtension = getPathExtname(filePath);
    return fileExtension === '.yaml' || fileExtension === '.yml';
};
exports.isYaml = isYaml;
var parseYamlOrJson = function (data, isYaml) {
    return isYaml ? js_yaml_1.default.load(data) : JSON.parse(data);
};
exports.parseYamlOrJson = parseYamlOrJson;
var stringifyToYamlOrJson = function (data, isYaml) {
    return isYaml ? js_yaml_1.default.dump(data) : JSON.stringify(data, null, 2);
};
exports.stringifyToYamlOrJson = stringifyToYamlOrJson;
var readFile = function (filePath) {
    try {
        return fs_1.default.readFileSync(filePath);
    }
    catch (error) {
        var err = error;
        logWrapper_1.default.fail(err.toString());
        process.exit(1);
    }
};
exports.readFile = readFile;
var writeFile = function (filePath, data) {
    try {
        fs_1.default.writeFileSync(filePath, data);
    }
    catch (error) {
        var err = error;
        logWrapper_1.default.fail(err.toString());
        process.exit(1);
    }
};
exports.writeFile = writeFile;
var appendFile = function (filePath, data, delimiter) {
    if (delimiter === void 0) { delimiter = '\n'; }
    try {
        fs_1.default.appendFileSync(filePath, "".concat(data).concat(delimiter));
    }
    catch (error) {
        var err = error;
        logWrapper_1.default.fail(err.toString());
        process.exit(1);
    }
};
exports.appendFile = appendFile;
var createNextNumberedFileName = function (filePath) {
    var escapeRegExp = function (string) {
        return string.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
    };
    try {
        if (!fileExists(filePath))
            return filePath;
        var dir = path_1.default.dirname(filePath);
        var baseNameWithoutExt = path_1.default.basename(filePath, path_1.default.extname(filePath));
        var ext = getPathExtname(filePath);
        var files = fs_1.default.readdirSync(dir);
        var regex = new RegExp("".concat(escapeRegExp(baseNameWithoutExt), "\\((\\d+)\\)(").concat(escapeRegExp(ext), ")?$"), 'i');
        var maxNumber = 0;
        for (var _i = 0, files_1 = files; _i < files_1.length; _i++) {
            var file = files_1[_i];
            var match = file.match(regex);
            if (match) {
                var number = parseInt(match[1], 10);
                maxNumber = Math.max(maxNumber, number);
            }
        }
        var newNumber = maxNumber + 1;
        var newFileName = "".concat(baseNameWithoutExt, "(").concat(newNumber, ")").concat(ext);
        return path_1.default.join(dir, newFileName);
    }
    catch (err) {
        logWrapper_1.default.fail("Error: Unable to create a new numbered file name for path '".concat(filePath, "'."));
        process.exit(1);
    }
};
exports.createNextNumberedFileName = createNextNumberedFileName;
var fileDataSplitter = function (data, split) {
    var defaultSplit = '\n';
    if (split === true) {
        split = defaultSplit;
    }
    var stringData = data.toString('utf-8');
    var splitRegex = new RegExp(split, 'g');
    return stringData.split(splitRegex);
};
exports.fileDataSplitter = fileDataSplitter;
