"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.simulateLog = exports.benchLog = exports.basicLog = exports.msgLog = exports.spinner = exports.singaleConfig = exports.signale = exports.Signale = void 0;
var signale_1 = require("signale");
Object.defineProperty(exports, "Signale", { enumerable: true, get: function () { return signale_1.Signale; } });
var chalk_1 = __importDefault(require("chalk"));
var util_1 = require("util");
var mqttErrorReason_1 = __importDefault(require("./mqttErrorReason"));
var state_1 = __importDefault(require("../state"));
var ora_1 = __importDefault(require("ora"));
var isLogFormat = state_1.default.getConfig('output') === 'log';
var singaleConfig = {
    displayLabel: false,
    displayDate: isLogFormat,
    displayTimestamp: isLogFormat,
    displayScope: false,
};
exports.singaleConfig = singaleConfig;
var signale = new signale_1.Signale({
    config: singaleConfig,
    types: {
        running: {
            badge: '❯',
            color: 'yellow',
            label: 'Running',
        },
    },
});
exports.signale = signale;
var spinner = (0, ora_1.default)();
exports.spinner = spinner;
var logWrapper = {
    await: function (msg) { return (isLogFormat ? signale.await(msg) : spinner.start(msg)); },
    success: function (msg) { return (isLogFormat ? signale.success(msg) : spinner.succeed(msg)); },
    fail: function (msg) { return (isLogFormat ? signale.error(msg) : spinner.fail(msg)); },
    warn: function (msg) { return (isLogFormat ? signale.warn(msg) : spinner.warn(msg)); },
    info: function (msg) { return (isLogFormat ? signale.info(msg) : spinner.info(msg)); },
    log: function (msg) { return signale.log(msg); },
    running: function (msg) { return signale.running(msg); },
};
var formatValue = function (value) { return (typeof value === 'object' ? (0, util_1.inspect)(value, false, null, true) : value); };
var msgLog = function (msg) {
    var payloadItems = msg.filter(function (item) { return item.label === 'payload'; });
    var subInfoItems = msg.filter(function (item) { return item.label !== 'payload'; });
    var payloadStrings = payloadItems.map(function (item) { return formatValue(item.value); });
    var subInfoStrings = subInfoItems.map(function (item) { return "".concat(chalk_1.default.green(item.label), ": ").concat(formatValue(item.value)); });
    var outputString = "".concat(subInfoStrings.join(', '), "\n").concat(payloadStrings.join('\n'));
    signale.log(isLogFormat ? outputString : "".concat(outputString, "\n"));
};
exports.msgLog = msgLog;
var basicLog = {
    connecting: function (config, host, port, topic, message) {
        if (port === void 0) { port = 1883; }
        if (!config) {
            logWrapper.await('Connecting...');
        }
        else {
            logWrapper.await("Connecting using configuration file, host: ".concat(host, ", port: ").concat(port).concat(topic ? ", topic: ".concat(topic) : '').concat(message ? ", message: ".concat(message) : ''));
        }
    },
    connected: function () { return logWrapper.success('Connected'); },
    subscribing: function (t) { return logWrapper.await("Subscribing to ".concat(t, "...")); },
    subscribed: function (t) { return logWrapper.success("Subscribed to ".concat(t)); },
    subscriptionNegated: function (sub, clientId) {
        var errorLog = "Subscription negated to \"".concat(sub.topic, "\" with code ").concat(sub.qos);
        if (clientId) {
            errorLog = "Client ID: ".concat(clientId, ", ").concat(errorLog);
        }
        logWrapper.fail(errorLog);
    },
    publishing: function () { return logWrapper.await('Message publishing...'); },
    published: function () { return logWrapper.success('Message published'); },
    enterToPublish: function () { return logWrapper.success('Connected, input and press Enter to publish'); },
    error: function (err) { return logWrapper.fail(err.toString()); },
    close: function () { return logWrapper.fail('Connection closed'); },
    reconnecting: function (retryTimes, maxReTryTimes) {
        return logWrapper.await("Reconnecting...[".concat(retryTimes, "/").concat(maxReTryTimes, "]"));
    },
    reconnectTimesLimit: function () { return logWrapper.fail('Exceed the maximum reconnect times limit, stop retry'); },
    disconnect: function (packet, clientId) {
        var reasonCode = packet.reasonCode;
        var reason = reasonCode === 0 ? 'Normal disconnection' : (0, mqttErrorReason_1.default)(reasonCode);
        logWrapper.warn("".concat(clientId ? "Client ID: ".concat(clientId, ", ") : '', "The Broker has actively disconnected, Reason: ").concat(reason, " (Code: ").concat(reasonCode, ")"));
    },
    fileReading: function () { return logWrapper.await('Reading file...'); },
    fileReadSuccess: function () { return logWrapper.success('Read file successfully'); },
};
exports.basicLog = basicLog;
var benchLog = {
    start: {
        conn: function (config, count, interval, host, port) {
            if (port === void 0) { port = 1883; }
            if (!config) {
                logWrapper.running("Starting connect benchmark, connections: ".concat(count, ", req interval: ").concat(interval, "ms"));
            }
            else {
                logWrapper.running("Starting connect benchmark, connections: ".concat(count, ", req interval: ").concat(interval, "ms, host: ").concat(host, ", port: ").concat(port));
            }
        },
        sub: function (config, count, interval, host, port, topic) {
            if (port === void 0) { port = 1883; }
            if (!config) {
                logWrapper.running("Starting subscribe benchmark, connections: ".concat(count, ", req interval: ").concat(interval, "ms, topic: ").concat(topic));
            }
            else {
                logWrapper.running("Starting subscribe benchmark, connections: ".concat(count, ", req interval: ").concat(interval, "ms, host: ").concat(host, ", port: ").concat(port, ", topic: ").concat(topic));
            }
        },
        pub: function (config, count, interval, messageInterval, host, port, topic, message) {
            if (port === void 0) { port = 1883; }
            if (!config) {
                logWrapper.running("Starting publish benchmark, connections: ".concat(count, ", req interval: ").concat(interval, "ms, message interval: ").concat(messageInterval, "ms"));
            }
            else {
                logWrapper.running("Starting publish benchmark, connections: ".concat(count, ", req interval: ").concat(interval, "ms, message interval: ").concat(messageInterval, "ms, host: ").concat(host, ", port: ").concat(port, ", topic: ").concat(topic, ", message: ").concat(message));
            }
        },
    },
    error: function (count, total, id, err) {
        return logWrapper.fail("[".concat(count, "/").concat(total, "] - Client ID: ").concat(id, ", ").concat(err));
    },
    close: function (count, total, id) {
        return logWrapper.fail("[".concat(count, "/").concat(total, "] - Client ID: ").concat(id, ", Connection closed"));
    },
    reconnecting: function (count, total, id) {
        return logWrapper.await("[".concat(count, "/").concat(total, "] - Client ID: ").concat(id, ", Reconnecting..."));
    },
    reconnected: function (count, total, id) {
        return logWrapper.success("[".concat(count, "/").concat(total, "] - Client ID: ").concat(id, ", Reconnected"));
    },
    reconnectTimesLimit: function (count, total, id) {
        return logWrapper.fail("[".concat(count, "/").concat(total, "] - Client ID: ").concat(id, ", Exceed the maximum reconnect times limit, stop retry"));
    },
};
exports.benchLog = benchLog;
var simulateLog = {
    start: {
        pub: function (config, count, interval, messageInterval, host, port, topic, scenario) {
            if (port === void 0) { port = 1883; }
            var message = "Starting publish simulation, scenario: ".concat(scenario, ", connections: ").concat(count, ", req interval: ").concat(interval, "ms, message interval: ").concat(messageInterval, "ms");
            if (config) {
                message += ", host: ".concat(host, ", port: ").concat(port, ", topic: ").concat(topic);
            }
            logWrapper.running(message);
        },
    },
};
exports.simulateLog = simulateLog;
exports.default = logWrapper;
